@@ -46,10 +46,7 @@ class KNN():
         index = faiss.IndexIVFFlat(quantizer, dim, nlist, faiss.METRIC_INNER_PRODUCT)
 
         self.use_gpu = use_gpu
-
         self.index = index
-        self.search_index = faiss.index_cpu_to_all_gpus(index) if use_gpu else index
-
         self.max_num_entries = max_num_entries
         self.cap_num_entries = cap_num_entries
         self.expire_memory_fn = expire_memory_fn
@@ -100,8 +97,10 @@ class KNN():
         if not self.index.is_trained:
             return np.full((x.shape[0], topk), -1)
 
-        self.search_index.nprobe = nprobe
-        distances, indices = self.search_index.search(x, k = topk)
+        search_index = faiss.index_cpu_to_all_gpus(self.index) if self.use_gpu else self.index
+
+        search_index.nprobe = nprobe
+        distances, indices = search_index.search(x, k = topk)
 
         if increment_hits:
             hits = count_intersect(self.ids, rearrange(indices, '... -> (...)'))
